import sys
from pathlib import Path

from alembic import context
from sqlalchemy import engine_from_config, pool

# Add app directory to path
sys.path.insert(0, str(Path(__file__).parent.parent))

# Import models
from app.db.base import Base
from app.core.config import settings

# Alembic Config object
config = context.config

# Set SQLAlchemy URL in Alembic config
config.set_main_option("sqlalchemy.url", settings.SQLALCHEMY_DATABASE_URL)

# Metadata for autogenerate support
target_metadata = Base.metadata


def run_migrations_offline():
    """Run migrations in 'offline' mode."""
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        compare_type=True,
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode."""
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        is_sqlite = connection.dialect.name == "sqlite"
        context.configure(
            connection=connection,
            target_metadata=target_metadata,
            compare_type=True,
            render_as_batch=is_sqlite,  # Enable batch mode for SQLite
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()